<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Stil Treguesi</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Mënyra Modë</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mënyra Efikase</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Mënyra Klasike</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Mënyra e Qendërzuar</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Majtas</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Pozicion</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mënyrë</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Në krye</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Në fund</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Djathtas</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Gjendje</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mbaje të Shfaqur</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mbaje të Fshehur</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Fshehje e Mençur</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Rregullim Paneli</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>